@@ -84,10 +84,15 @@ cc      COMMON /COM70/NH
 cc      COMMON /COM80/A
 cc      COMMON /COM81/B
 cc      COMMON /COM82/AW
+c common /COM99/
+      INTEGER ISWR
       COMMON /COM99/ISWR
 cc      COMMON /COM87/ICONT
+c common /COM101/
       DOUBLE PRECISION AICO
       COMMON /COM101/AICO
+c common /COM102/
+      INTEGER KSWR
       COMMON /COM102/KSWR
 cc      COMMON /COM199/AICD
 cc      DIMENSION CYY1(160,5,5)
@@ -114,6 +119,8 @@ cxx      DIMENSION CXY1(100,ID,ID),CXX1(51,ID,ID),CXV1(51,ID,K)
      2                 BM(ID,ID,MJ6), AU(ID,ID,MJ7), ZZ(ID,ID,MJ7),
      3                 C0(ID,ID), AICD 
 c local
+      INTEGER I, II, IAW, IDP1, IG, ISFIN, ISWRO, J, JJ, JL, JS, KK,
+     1        L, M
       DOUBLE PRECISION CYY1(MJ3,ID,ID), OB(K,ID), X(MJ4), R(MJ4),
      1                 AW(JAW), OAW(JAW), O(50,ID,K), Q(50,K,ID),
      2                 X1(50,K,K), X2(50,ID,ID), CXY1(100,ID,ID),
@@ -510,6 +517,8 @@ C     THE GRADIENT OF LOG(DET CXX(0))
 cxx      IMPLICIT REAL*8(A-H,O-Z)
 cc	COMMON /COM81/B
 cc	COMMON /COM82/AW
+c common /COM102/
+      INTEGER KSWR
       COMMON /COM102/KSWR
 cc	DIMENSION CYY1(160,5,5),B(10,5),AW(50)
 cc	DIMENSION IDD(10),IR(10),IJ(5),IK(5)
@@ -519,12 +528,14 @@ cxx      DIMENSION NH(K),IDD(K),IR(K),IJ(ID),IK(ID)
 cxx      DIMENSION X(MJ4),C0(ID,ID),GR(MJ4)
 cxx      DIMENSION O(50,ID,K),Q(50,K,ID),X1(50,K,K),X2(50,ID,ID)
 cxx      DIMENSION CXY1(100,ID,ID),CXX1(51,ID,ID),CXV1(51,ID,K)
-      INTEGER MJ3, IAW, NH(K), IDD(K), IR(K), IJ(ID), IK(ID), M, L, K,
-     1        ID, MJ4, IG
+      INTEGER MJ3, IAW, M, L, K, ID, MJ4, IG, NH(K), IDD(K), 
+     1        IR(K), IJ(ID), IK(ID)
       DOUBLE PRECISION CYY1(MJ3,ID,ID), B(K,ID), AW(IAW), X(MJ4),
      1                 C0(ID,ID), GR(MJ4), O(50,ID,K), Q(50,K,ID),
      2                 X1(50,K,K), X2(50,ID,ID), CXY1(100,ID,ID),
      3                 CXX1(51,ID,ID), CXV1(51,ID,K)
+c local
+      INTEGER I, IDP1, IG1, IG2, J, JJ, KK
 C
       DO 600 I=1,IAW
 cxx  600 AW(I)=X(I)
@@ -593,6 +604,8 @@ cc      COMMON /COM15/X1
 cc	COMMON /COM60/IDD,IR
 cc	COMMON /COM81/B
 cc	COMMON /COM82/AW
+c common /COM99/
+      INTEGER ISWR
       COMMON /COM99/ISWR
 cc	DIMENSION IDD(10),IR(10)
 cc	DIMENSION AW(50),B(10,5)
@@ -606,8 +619,10 @@ cxx      DIMENSION X1(50,K,K)
 cxx      DIMENSION V(K,K),AV(K,K)
 cxx      DIMENSION X(ID,K),Y(ID,K),U(K,K)
 cxx      DIMENSION AU(K,K)
-      INTEGER IAW,  NH(K), IDD(K), IR(K), K, ID, M, IG1
+      INTEGER IAW, K, ID, M, IG1, NH(K), IDD(K), IR(K)
       DOUBLE PRECISION B(K,ID), AW(IAW), X1(50,K,K)
+c local
+      INTEGER I, IH, ITINP, J, JJ, LH, NS, NSM1
       DOUBLE PRECISION V(K,K), AV(K,K), X(ID,K), Y(ID,K), U(K,K),
      1                 AU(K,K), CST0, CST1, CONSTM, CONSTD, SUM, XMAX
 C
@@ -782,6 +797,8 @@ cc	COMMON /COM60/IDD,IR
 cc	COMMON /COM81/B
 cc	COMMON /COM82/AW
 cc      COMMON /COM2/Q
+c common /COM99/
+      INTEGER ISWR
       COMMON /COM99/ISWR
 cc      DIMENSION Q(50,10,5)
 cc	DIMENSION IDD(10),IR(10)
@@ -795,8 +812,10 @@ cxx      DIMENSION X2(50,ID,ID)
 cxx      DIMENSION AW(IAW),B(K,ID)
 cxx      DIMENSION U(K,ID)
 cxx      DIMENSION XX(ID,ID),AU(K,ID)
-      INTEGER IAW, IDD(K), IR(K), K, ID, KK, IG2
+      INTEGER IAW, K, ID, KK, IG2, IDD(K), IR(K)
       DOUBLE PRECISION B(K,ID), AW(IAW), Q(50,K,ID), X2(50,ID,ID)
+c local
+      INTEGER I, IDP1, IH, IPD, J, JJ, KMD, LH, NS, NSM1
       DOUBLE PRECISION U(K,ID), XX(ID,ID), XMAX, AU(K,ID), CST0, CST1,
      1                 CONSTD, SUM
 C
@@ -927,6 +946,8 @@ cxx      DIMENSION C0(ID,ID),C0I(ID,ID)
 cxx      DIMENSION X(ID,K),OO(ID,K)
       INTEGER K, ID, M
       DOUBLE PRECISION C0(ID,ID), O(50,ID,K), X1(50,K,K)
+c local
+      INTEGER I, J, MP1, NS, NSM1
       DOUBLE PRECISION C0I(ID,ID), X(ID,K), OO(ID,K), C0DET
 C
 C     INVERSE OF C0 COMPUTATION
@@ -971,7 +992,11 @@ cxx      IMPLICIT REAL*8(A-H,O-Z)
 cc	DIMENSION XX(MJ6,MJ7)
 cxx      DIMENSION XX(IA,IB)
       INTEGER IA, IB
-      DOUBLE PRECISION XX(IA,IB), XMAX, T
+      DOUBLE PRECISION XX(IA,IB), XMAX
+c local
+      INTEGER I, J
+      DOUBLE PRECISION T
+c
       XMAX=0.0D-00
       DO 709 I=1,IA
       DO 710 J=1,IB
@@ -1009,9 +1034,11 @@ cxx      DIMENSION OO(K,ID),CXX(ID,ID),CXV(ID,K)
 cxx      DIMENSION ZA(K,K),ZZA(K,K),ZB(K,ID),ZZB(K,ID)
 cxx      DIMENSION GR(MJ4),ZAW(MJ4)
 cxx      DIMENSION IJ(ID),IK(ID)
-      INTEGER IJ(ID), IK(ID), M, K, ID, IAW, MJ4
+      INTEGER M, K, ID, IAW, MJ4, IJ(ID), IK(ID)
       DOUBLE PRECISION GR(MJ4), O(50,ID,K), CXX1(51,ID,ID),
      1                 CXV1(51,ID,K)
+c local
+      INTEGER I, IDP1, IJK, IKSJ, J, JJ, JL, KS, MP1,  NSP1, NSP2
       DOUBLE PRECISION OO(K,ID), CXX(ID,ID), CXV(ID,K), ZA(K,K),
      1                 ZZA(K,K), ZB(K,ID), ZZB(K,ID), ZAW(MJ4),
      2                 CST0, CST1, CST2
@@ -1109,6 +1136,8 @@ cxx      DIMENSION X2(50,ID,ID),CYY1(MJ3,ID,ID),CXY1(100,ID,ID)
 cxx      DIMENSION XX(ID,ID),CYY(ID,ID),Z(ID,ID),ZZ(ID,ID)
       INTEGER MJ3, M, L, ID
       DOUBLE PRECISION CYY1(MJ3,ID,ID), X2(50,ID,ID), CXY1(100,ID,ID)
+c local
+      INTEGER I, J, LMS, LMSP1, LP1, LS, LSL, LSP1, MS, MSP1
       DOUBLE PRECISION XX(ID,ID), CYY(ID,ID), Z(ID,ID), ZZ(ID,ID), CST0
 C
 C
@@ -1185,6 +1214,8 @@ cxx      DIMENSION C0(ID,ID)
       INTEGER M, KK, ID
       DOUBLE PRECISION C0(ID,ID), X2(50,ID,ID), CXY1(100,ID,ID),
      1                 CXX1(51,ID,ID)
+c local
+      INTEGER I, J, KKP1, MSP1, NS, NSL, NSP1, NSPMS1
       DOUBLE PRECISION XX(ID,ID), CXY(ID,ID), Z(ID,ID), ZZ(ID,ID), CST0
 C
 C
@@ -1246,6 +1277,8 @@ cxx      DIMENSION Q(50,K,ID),CXY1(100,ID,ID),CXV1(51,ID,K)
 cxx      DIMENSION QQ(ID,K-ID),CXY(ID,ID),Z(ID,K-ID),ZZ(ID,K-ID)
       INTEGER M, L, K, ID
       DOUBLE PRECISION Q(50,K,ID), CXY1(100,ID,ID), CXV1(51,ID,K)
+c local
+      INTEGER I, IDP1, J, JMD, KMD, LP1, MNSP1, MP2, MS, MSP1, NSP1 
       DOUBLE PRECISION QQ(ID,K-ID), CXY(ID,ID), Z(ID,K-ID), ZZ(ID,K-ID),
      1                 CST0
 C
@@ -1308,7 +1341,10 @@ cc	DIMENSION NH(10),IDD(10),IR(10)
 cc	DIMENSION IJ(5),IK(5)
 cxx      DIMENSION NH(K),IDD(K),IR(K)
 cxx      DIMENSION IJ(ID),IK(ID)
-      INTEGER NH(K), IDD(K), IR(K), IJ(ID), IK(ID), K, ID, IAW
+      INTEGER K, ID, IAW, NH(K), IDD(K), IR(K), IJ(ID), IK(ID)
+c local
+      INTEGER I, IDH, IFP, J, LR
+c
       IAW = 0
       IFP = 0
       DO 100 I=1,K
@@ -1348,8 +1384,11 @@ cc	DIMENSION A(10,10),AW(50)
 cc	DIMENSION IJ(5),IK(5)
 cxx      DIMENSION A(K,K),AW(IAW)
 cxx      DIMENSION IJ(ID),IK(ID)
-      INTEGER IJ(ID), IK(ID), K, ID, IAW
+      INTEGER K, ID, IAW, IJ(ID), IK(ID)
       DOUBLE PRECISION A(K,K), AW(IAW)
+c local
+      INTEGER IJK, IKSJ, J, JL, KS
+c
 cc	IKSUM=0
       IKSJ=0
       DO 300 KS=1,ID
@@ -1377,8 +1416,10 @@ cc	DIMENSION AW(50),IDD(10),IR(10)
 cc	DIMENSION Z(MJ3,MJ4),ZP(MJ3,MJ4)
 cxx      DIMENSION AW(IAW),IDD(K),IR(K)
 cxx      DIMENSION Z(K,IC),ZP(K,IC)
-      INTEGER IAW, IDD(K), IR(K), K, IC
+      INTEGER K, IC, IAW, IDD(K), IR(K)
       DOUBLE PRECISION AW(IAW), Z(K,IC), ZP(K,IC)
+c local
+      INTEGER I, IRI, J, JJ, NI, NI0, NI0J
       DOUBLE PRECISION CST0, SUM
       CST0=0.0D-00
       NI=0
@@ -1420,6 +1461,8 @@ cxx      DIMENSION O(50,ID,K),CM1(50,K,K)
 cxx      DIMENSION OO(K,ID),XX(ID,K),Z(K,K),ZZ(K,K)
       INTEGER M, K, ID
       DOUBLE PRECISION O(50,ID,K), CM1(50,K,K)
+c local
+      INTEGER I, J, MNSP1, MP1, MS, MSP1, NSL, NSP1
       DOUBLE PRECISION OO(K,ID), XX(ID,K), Z(K,K), ZZ(K,K), CST0
 C
 C
@@ -1483,10 +1526,13 @@ cxx      DIMENSION CXV2(51,ID,K)
 cxx      DIMENSION HS(MJ4,MJ4)
 cxx      DIMENSION O(50,ID,K),Q(50,K,ID),X2(50,ID,ID)
 cxx      DIMENSION CXY1(100,ID,ID),CXY2(50,ID,ID)
-      INTEGER IJ(ID), IK(ID), M, L, K, ID, IAW, MJ3, MJ4
+      INTEGER M, L, K, ID, IAW, MJ3, MJ4, IJ(ID), IK(ID)
       DOUBLE PRECISION CYY1(MJ3,ID,ID), HS(MJ4,MJ4), O(50,ID,K),
      1                 Q(50,K,ID), CM1(50,K,K), X2(50,ID,ID),
      2                 CXY1(100,ID,ID), CXX1(51,ID,ID), CXV1(51,ID,K)
+c local
+      INTEGER I, I2, IDP1, IJK, IJK2, IKSJ, IKSJ2, J, J2, JJ, JJ2, JL,
+     1        JL2, KS, KS2, MS, MP1, MSP1, MSP2
       DOUBLE PRECISION CVV1(50,K,K), CXV2(51,ID,K), CXY2(50,ID,ID),
      1                 CST2, SUMBB, SUMAB, SUMAA
 C
@@ -1614,6 +1660,8 @@ cxx      DIMENSION QQ(K-ID,ID),CXV(ID,K),Z(K-ID,K),ZZ(K-ID,K)
       INTEGER M, L, K, ID
       DOUBLE PRECISION Q(50,K,ID), CYV1(51,ID,K), CVV1(50,K,K),
      1                 CYV2(51,ID,K)
+c local
+      INTEGER I, IDP1, IMD, J, KMD, LP1, LSP1, ML, MP1, MSP1
       DOUBLE PRECISION QQ(K-ID,ID), CXV(ID,K), Z(K-ID,K), ZZ(K-ID,K),
      1                 CST0, CST1
 C
@@ -1696,6 +1744,8 @@ cxx      DIMENSION Q(50,K,ID),CYY1(MJ3,ID,ID),CYV1(51,ID,K)
 cxx      DIMENSION QQ(ID,K-ID),CYY(ID,ID),Z(ID,K-ID),ZZ(ID,K-ID)
       INTEGER MJ3, M, L, K, ID
       DOUBLE PRECISION CYY1(MJ3,ID,ID), Q(50,K,ID), CYV1(51,ID,K)
+c local
+      INTEGER I, IDP1, J, JMD, KMD, LP1, LSP1, ML, MP1, MSP1
       DOUBLE PRECISION QQ(ID,K-ID), CYY(ID,ID), Z(ID,K-ID), ZZ(ID,K-ID),
      1                 CST0
 C
@@ -1763,6 +1813,8 @@ cxx      DIMENSION Q(50,K,ID),CYY1(MJ3,ID,ID),CYV2(51,ID,K)
 cxx      DIMENSION QQ(ID,K-ID),CYY(ID,ID),Z(ID,K-ID),ZZ(ID,K-ID)
       INTEGER MJ3, L, K, ID
       DOUBLE PRECISION CYY1(MJ3,ID,ID), Q(50,K,ID), CYV2(51,ID,K)
+c local
+      INTEGER I, IDP1, J, JMD, KMD, LP1, LSP1, ML, MSP1
       DOUBLE PRECISION QQ(ID,K-ID), CYY(ID,ID), Z(ID,K-ID), ZZ(ID,K-ID),
      1                 CST0
 C
@@ -1840,6 +1892,8 @@ cxx      DIMENSION QQ(ID,K-ID),CXY(ID,ID),Z(ID,K-ID),ZZ(ID,K-ID)
       INTEGER M, L, K, ID
       DOUBLE PRECISION Q(50,K,ID), CXY1(100,ID,ID), CXY2(50,ID,ID),
      1                 CXV2(51,ID,K)
+c local
+      INTEGER I, IDP1, J, JMD, KMD, LP1, LSP1, ML, MSP1
       DOUBLE PRECISION QQ(ID,K-ID), CXY(ID,ID), Z(ID,K-ID), ZZ(ID,K-ID),
      1                 CST0
 C
@@ -1917,6 +1971,8 @@ cxx      DIMENSION X2(50,ID,ID),CYY1(MJ3,ID,ID),CXY2(50,ID,ID)
 cxx      DIMENSION XX(ID,ID),CYY(ID,ID),Z(ID,ID),ZZ(ID,ID)
       INTEGER MJ3, M, L, ID
       DOUBLE PRECISION CYY1(MJ3,ID,ID), X2(50,ID,ID), CXY2(50,ID,ID)
+c local
+      INTEGER I, J, LP1, LSP1, ML, MSP1
       DOUBLE PRECISION XX(ID,ID), CYY(ID,ID), Z(ID,ID), ZZ(ID,ID), CST0
 C
       CST0=0.0D-00
@@ -1984,12 +2040,14 @@ cc      DIMENSION AW(IAW),IDD(K),IR(K)
 cxx      DIMENSION AW(IAW),NH(K),IDD(K),IR(K)
 cxx      DIMENSION O(50,ID,K),Q(50,K,ID),X1(50,K,K),X2(50,ID,ID)
 cxx      DIMENSION CXY1(100,ID,ID),CXX1(51,ID,ID),CXV1(51,ID,K)
-      INTEGER MJ3, IAW, NH(K), IDD(K), IR(K), IJ(ID), IK(ID), N, K,
-     1        ID, IPQ, MJ4, ISWRO
+      INTEGER MJ3, IAW, N, K, ID, IPQ, MJ4, ISWRO, NH(K), IDD(K),
+     1        IR(K), IJ(ID), IK(ID)
       DOUBLE PRECISION CYY1(MJ3,ID,ID), B(K,ID), AW(IAW), VD(MJ4,MJ4),
      1                 X(MJ4), C0(ID,ID), G(MJ4), R(MJ4), AICD,
      2                 O(50,ID,K), Q(50,K,ID), X1(50,K,K), X2(50,ID,ID),
      3                 CXY1(100,ID,ID), CXX1(51,ID,ID), CXV1(51,ID,K)
+c local
+      INTEGER I, IG, IPQ2, IRAM, ITN, ITNS, ISPHAI, IPHAI, J, L, M
       DOUBLE PRECISION C0D(ID,ID), SX(MJ4), SC0(ID,ID), SC0D(ID,ID),
      1                 SG(MJ4), SR(MJ4), CST0, CST1, CST2, CST01, CST05,
      2                 CONSTA, CONSTB, EPS1, EPS3, EPS4, EPS5, AIPQ,
@@ -2278,11 +2336,14 @@ cc	DIMENSION W0(5,5),Z(5,5),ZZ(5,5)
 cxx      DIMENSION BA(ID,MJ6),B0(ID,ID),BM(ID,MJ6)
 cxx      DIMENSION U(K,ID),AU(K,ID,MJ7),AAU(ID,ID,MJ7)
 cxx      DIMENSION BBM(ID,ID,MJ6),W0(ID,ID),Z(ID,ID),ZZ(ID,ID,MJ7)
-      INTEGER IAW, IH(K), IDD(K), IR(K), IK(ID), ID, ICONT, K,
-     1        IQM, MJ6, MJ7
+      INTEGER IAW, ID, ICONT, K, IQM, MJ6, MJ7, IH(K), IDD(K), IR(K),
+     1        IK(ID)
       DOUBLE PRECISION B(K,ID), AW(IAW), BBM(ID,ID,MJ6),
      1                 AAU(ID,ID,MJ7), ZZ(ID,ID,MJ7)
-      INTEGER IO(K)
+c local
+      INTEGER I, IDL, IDL1, IKI, IMAJ, IQ, IQD, IQM1, IQMAX, IRD, IRS, 
+     1        ISR, ISRD, ISUM, IT, ITM1, J, JA, JB, JB1, JBJ, JDQ,
+     2        JMA, JO, JT, JTB, JTBJ, JTW, JTWJ, JW, JWJ, NS, IO(K)
       DOUBLE PRECISION BA(ID,MJ6), B0(ID,ID), BDET, BM(ID,MJ6), U(K,ID),
      1                 AU(K,ID,MJ7), W0(ID,ID), Z(ID,ID), CST0, CST1
 C     BA COMPUTATION
@@ -2495,9 +2556,10 @@ cxx      DIMENSION IJ(ID),NH(K),IR(K)
 cc      DIMENSION IDUMMY(ID)
 cxx      DIMENSION IDD(K)
 cxx      DIMENSION IO(K)
-      INTEGER IAW, NH(K), IDD(K), IR(K), K, ID 
+      INTEGER IAW, K, ID, NH(K), IDD(K), IR(K)
       DOUBLE PRECISION B(K,ID), AW(IAW)
-      INTEGER IO(K)
+c local
+      INTEGER I, IDP1, IKSJ, IM, IOI, IOR, J, JL, KS, IO(K)
       DOUBLE PRECISION RO9, SCALE
 C
       RO9=0.95D-00
@@ -2551,6 +2613,8 @@ cc	DIMENSION X(MJ,MJ)
 cxx      DIMENSION X(MM,MM)
       INTEGER MM
       DOUBLE PRECISION X(MM,MM), XDETMI
+c local
+      INTEGER I, I1, J, JJ, K, MM1
       DOUBLE PRECISION CST0, CST1, XXC, XC
       CST0=0.0D-00
       CST1=1.0D-00
