@@ -34,7 +34,7 @@ cxx      DIMENSION G(L+1),RS1(IP,IP),RS2(IP,IP,H+1),R(IP,IP,H+1)
 c local
       INTEGER I, I1, II, J, JF, JJ, JJF, LG, H1
       DOUBLE PRECISION G(L+1), GR, GI, CST0, CST1
-      COMPLEX(kind(0d0)) :: X(IP,IP), XDET
+      COMPLEX(KIND(0.0D0)) X(IP,IP), XDET
 C     INPUT / OUTPUT DATA FILE OPEN
 c	CALL SETWND
 c	CALL FLOPN2(NFL)
@@ -96,7 +96,7 @@ cxx   44 LG=L
 c      CALL FGER1
       CALL FGER1(G,GR,GI,LG,H,JJF)
 cxx      X(II,JJ)=DCMPLX(GR,GI)
-      X(II,JJ)=CMPLX(GR,GI,KIND=8)
+      X(II,JJ)=CMPLX(GR,GI,KIND(0.0D0))
    41 CONTINUE
    40 CONTINUE
 C     INVERSE OF AF (COMPLEX) COMPUTATION
