@@ -33,12 +33,12 @@ cxx      DIMENSION SD(IP,IP),A(L,IP,IP),B(K,IP,IP),X(IP,IP),Y(IP,IP,H+1)
 cxx      DIMENSION Z(IP,IP),G(L+K+1),CH(IP,IP,H+1)
       INTEGER H, L, IP, K
       DOUBLE PRECISION SD(IP,IP), A(L,IP,IP), B(K,IP,IP), CH(IP,IP,H+1)
-      COMPLEX(kind(0d0)) :: Y(IP,IP,H+1)
+      COMPLEX(KIND(0.0D0)) Y(IP,IP,H+1)
 c local
       INTEGER I, I1, II, IM1, JF, JJ, JJF, LG, H1
       DOUBLE PRECISION G(L+K+1), CST0,  CST1, GR, GI, RYI, RYJ, RRYIJ,
      1                 RIYIJ
-      COMPLEX(kind(0d0)) :: X(IP,IP), Z(IP,IP), XDET
+      COMPLEX(KIND(0.0D0)) X(IP,IP), Z(IP,IP), XDET
 C     INPUT / OUTPUT DATA FILE OPEN
 c	CALL SETWND
 c	CALL FLOPN2(NFL)
@@ -119,7 +119,7 @@ cxx   24 LG=K
 c      CALL FGER1
       CALL FGER1(G,GR,GI,LG,H,JJF)
 cxx      X(II,JJ)=DCMPLX(GR,GI)
-      X(II,JJ)=CMPLX(GR,GI,KIND=8)
+      X(II,JJ)=CMPLX(GR,GI,KIND(0.0D0))
    21 CONTINUE
    20 CONTINUE
 C     BF*SD*CONJG(BF') COMPUTATION
@@ -152,7 +152,7 @@ cxx   44 LG=L
 c      CALL FGER1
       CALL FGER1(G,GR,GI,LG,H,JJF)
 cxx      X(II,JJ)=DCMPLX(GR,GI)
-      X(II,JJ)=CMPLX(GR,GI,KIND=8)
+      X(II,JJ)=CMPLX(GR,GI,KIND(0.0D0))
    41 CONTINUE
    40 CONTINUE
 C     INVERSE OF AF (COMPLEX) COMPUTATION
@@ -235,11 +235,11 @@ cxx      DIMENSION X(MM,NN),Y(NN,NN),Z(MM,MM)
 cxx      DIMENSION Y1(MM,NN)
 cxx      DOUBLE PRECISION CST0
       INTEGER MM, NN
-      COMPLEX(kind(0d0)) :: X(MM,NN), Y(NN,NN), Z(MM,MM)
+      COMPLEX(KIND(0.0D0)) X(MM,NN), Y(NN,NN), Z(MM,MM)
 c local
       INTEGER I, J, K
       DOUBLE PRECISION CST0
-      COMPLEX(kind(0d0)) :: Y1(MM,NN), XSUM
+      COMPLEX(KIND(0.0D0)) Y1(MM,NN), XSUM
       CST0=0.0D-00
       DO 10 I=1,MM
 cxx      DO 10 J=1,NN
