@@ -34,7 +34,7 @@ cxx      DIMENSION PXX(H+1)
       INTEGER H, L, K
       DOUBLE PRECISION SGME2, A(L), B(K), PXX(H+1)
 c local
-      INTEGER H1
+      INTEGER I, I1, K1, L1, H1
       DOUBLE PRECISION G(L+K+1), GR1(H+1), GI1(H+1), GR2(H+1), GI2(H+1)
 C
 C     INPUT / OUTPUT DATA FILE OPEN
